import { Ed25519Keypair } from "@mysten/sui.js/keypairs/ed25519";
import { SuiPlatform } from "./platform.js";
export async function getSuiSigner(rpc, privateKey) {
    const [, chain] = await SuiPlatform.chainFromRpc(rpc);
    return new SuiSigner(chain, rpc, Ed25519Keypair.deriveKeypair(privateKey, "m/44'/784'/0'/0'/0'"));
}
// SuiSigner implements SignOnlySender
export class SuiSigner {
    _chain;
    _client;
    _signer;
    constructor(_chain, _client, _signer) {
        this._chain = _chain;
        this._client = _client;
        this._signer = _signer;
    }
    chain() {
        return this._chain;
    }
    address() {
        return this._signer.toSuiAddress();
    }
    async signAndSend(txns) {
        const txids = [];
        for (const tx of txns) {
            const { description, transaction } = tx;
            console.log(`Signing ${description} for ${this.address()}`);
            const result = await this._client.signAndExecuteTransactionBlock({
                transactionBlock: transaction,
                signer: this._signer,
            });
            txids.push(result.digest);
        }
        return txids;
    }
}
//# sourceMappingURL=signer.js.map